@@ -170,6 +170,12 @@ function Span(s, attr)
   return "<span" .. attributes(attr) .. ">" .. s .. "</span>"
 end
 
+function RawInline(format, str)
+  if format == "html" then
+    return str
+  end
+end
+
 function Cite(s, cs)
   local ids = {}
   for _,cit in ipairs(cs) do
@@ -200,6 +206,11 @@ function HorizontalRule()
   return "<hr/>"
 end
 
+function LineBlock(ls)
+  return '<div style="white-space: pre-line;">' .. table.concat(ls, '\n') ..
+         '</div>'
+end
+
 function CodeBlock(s, attr)
   -- If code block has class 'dot', pipe the contents through dot
   -- and base64, and include the base64-encoded png as a data: URL.
@@ -307,6 +318,12 @@ function Table(caption, aligns, widths, headers, rows)
   return table.concat(buffer,'\n')
 end
 
+function RawBlock(format, str)
+  if format == "html" then
+    return str
+  end
+end
+
 function Div(s, attr)
   return "<div" .. attributes(attr) .. ">\n" .. s .. "</div>"
 end
